@@ -1,4 +1,4 @@
-from PyQt5.QtWidgets import QComboBox
+from qtpy.QtWidgets import QComboBox
 
 from napari_allencell_segmenter.widgets.form import FormRow
 
@@ -12,12 +12,13 @@ class UiUtils:
         """
         dropdown = QComboBox()
         dropdown.setDisabled(not enabled)
+        dropdown.setStyleSheet("QComboBox { combobox-popup: 0; }")
         if placeholder is not None:
             dropdown.addItem(placeholder)
         if options is not None:
             str_options = [str(option) for option in options]
             dropdown.addItems(str_options)
-        if placeholder is None and default is not None:
+        if placeholder is None and default is not None and options is not None:
             default_index = options.index(default)
             dropdown.setCurrentIndex(default_index)
 
