@@ -3,16 +3,16 @@ from typing import List
 from aicssegmentation.workflow import WorkflowDefinition
 import cv2
 import numpy as np
-from PyQt5.QtWidgets import (
+from qtpy.QtWidgets import (
     QPushButton,
     QHBoxLayout,
     QVBoxLayout,
     QLabel,
     QWidget,
 )
-from PyQt5.QtGui import QIcon, QPixmap, QImage
-from PyQt5 import QtCore
-from PyQt5.QtCore import pyqtSignal
+from qtpy.QtGui import QIcon, QPixmap, QImage
+from qtpy import QtCore
+from qtpy.QtCore import Signal
 
 from napari_allencell_segmenter.widgets.form import Form, FormRow
 from napari_allencell_segmenter._style import PAGE_CONTENT_WIDTH, Style
@@ -28,7 +28,7 @@ class WorkflowThumbnails(QWidget):
             workflow definitions to display as buttons
     """
 
-    workflowSelected = pyqtSignal(str)  # signal: emitted when a workflow is selected
+    workflowSelected = Signal(str)  # signal: emitted when a workflow is selected
 
     def __init__(self, workflows: List[WorkflowDefinition] = None):
         super().__init__()
@@ -123,6 +123,7 @@ class WorkflowThumbnails(QWidget):
             button.setIcon(QIcon(image))
             button.setIconSize(QtCore.QSize(PAGE_CONTENT_WIDTH - 40, 200))
             button.setFixedSize(PAGE_CONTENT_WIDTH, 200)
+            button.setToolTip(workflow.name)
 
             button.setEnabled(False)
             button.setObjectName(workflow.name)
